@@ -15,8 +15,6 @@
  *           Bell Labs Innovations for Lucent Technologies
  *           mmclennan@lucent.com
  *           http://www.tcltk.com/itcl
- *
- *     RCS:  $Id: itk_option.c,v 1.4 2002/08/11 04:12:54 davygrvy Exp $
  * ========================================================================
  *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
  * ------------------------------------------------------------------------
@@ -84,13 +82,13 @@ Itk_ClassOptionDefineCmd(clientData, interp, objc, objv)
 
     switchName = Tcl_GetStringFromObj(objv[1], (int*)NULL);
     if (*switchName != '-') {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+        Tcl_AppendResult(interp,
             "bad option name \"", switchName, "\": should be -", switchName,
             (char*)NULL);
         return TCL_ERROR;
     }
     if (strstr(switchName, ".")) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+        Tcl_AppendResult(interp,
             "bad option name \"", switchName, "\": illegal character \".\"",
             (char*)NULL);
         return TCL_ERROR;
@@ -98,7 +96,7 @@ Itk_ClassOptionDefineCmd(clientData, interp, objc, objv)
 
     resName = Tcl_GetStringFromObj(objv[2], (int*)NULL);
     if (!islower((int)*resName)) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+        Tcl_AppendResult(interp,
             "bad resource name \"", resName,
             "\": should start with a lower case letter",
             (char*)NULL);
@@ -107,7 +105,7 @@ Itk_ClassOptionDefineCmd(clientData, interp, objc, objv)
 
     resClass = Tcl_GetStringFromObj(objv[3], (int*)NULL);
     if (!isupper((int)*resClass)) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+        Tcl_AppendResult(interp,
             "bad resource class \"", resClass,
             "\": should start with an upper case letter",
             (char*)NULL);
@@ -126,7 +124,7 @@ Itk_ClassOptionDefineCmd(clientData, interp, objc, objv)
     entry = Tcl_CreateHashEntry(&optTable->options, switchName, &newEntry);
 
     if (!newEntry) {
-        Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+        Tcl_AppendResult(interp,
             "option \"", switchName, "\" already defined in class \"",
             cdefn->fullname, "\"",
             (char*)NULL);
@@ -176,7 +174,7 @@ Itk_ClassOptionIllegalCmd(clientData, interp, objc, objv)
 {
     char *op = Tcl_GetStringFromObj(objv[0], (int*)NULL);
 
-    Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+    Tcl_AppendResult(interp,
         "can only ", op, " options for a specific widget\n",
         "(move this command into the constructor)",
         (char*)NULL);
@@ -250,7 +248,7 @@ Itk_CreateClassOptTable(interp, cdefn)
     Tcl_HashTable *itkClasses;
     Tcl_HashEntry *entry;
     ItkClassOptTable *optTable;
-    Tcl_CallFrame frame;
+    Itcl_CallFrame frame;
 
     /*
      *  Look for the specified class definition in the table.
@@ -271,13 +269,13 @@ Itk_CreateClassOptTable(interp, cdefn)
 
         Tcl_SetHashValue(entry, (ClientData)optTable);
 
-        result = Tcl_PushCallFrame(interp, &frame,
+        result = Tcl_PushCallFrame(interp, (Tcl_CallFrame *) &frame,
              cdefn->namesp, /* isProcCallFrame */ 0);
 
         if (result == TCL_OK) {
             Tcl_TraceVar(interp, "_itk_option_data",
                 (TCL_TRACE_UNSETS | TCL_NAMESPACE_ONLY),
-                ItkTraceClassDestroy, (ClientData)cdefn);
+                (Tcl_VarTraceProc*) ItkTraceClassDestroy, (ClientData)cdefn);
             Tcl_PopCallFrame(interp);
         }
     }
@@ -418,7 +416,8 @@ Itk_CreateClassOption(interp, cdefn, switchName, resName, resClass,
             return TCL_ERROR;
         }
         Itcl_PreserveData((ClientData)mcode);
-        Itcl_EventuallyFree((ClientData)mcode, Itcl_DeleteMemberCode);
+        Itcl_EventuallyFree((ClientData)mcode,
+		(Tcl_FreeProc*) Itcl_DeleteMemberCode);
     }
     else {
         mcode = NULL;
